@@ -5,9 +5,11 @@ from future.utils import with_metaclass
 from bleach import clean
 
 from django.conf import settings
+from django.contrib.admin.widgets import AdminTextareaWidget
 from django.core.exceptions import ImproperlyConfigured, ValidationError
 from django.db import models
 from django.forms import MultipleChoiceField
+from django.utils.encoding import force_text
 from django.utils.text import capfirst
 from django.utils.translation import ugettext_lazy as _
 
@@ -35,7 +37,8 @@ class RichTextField(models.TextField):
         Apply the widget class defined by the
         ``RICHTEXT_WIDGET_CLASS`` setting.
         """
-        if "widget" not in kwargs:
+        default = kwargs.get("widget", None) or AdminTextareaWidget
+        if default is AdminTextareaWidget:
             from mezzanine.conf import settings
             richtext_widget_path = settings.RICHTEXT_WIDGET_CLASS
             try:
@@ -108,6 +111,16 @@ class MultiChoiceField(with_metaclass(models.SubfieldBase, models.CharField)):
         value = self._get_val_from_obj(obj)
         return ",".join(value)
 
+    def contribute_to_class(self, cls, name):
+        def _get_FIELD_display(self, field):
+            value = getattr(self, field.attname)
+            value = force_text(" & ".join([dict(field.choices).get(v, v)
+                                           for v in value]), strings_only=True)
+            return value
+        setattr(cls, '_get_FIELD_display', _get_FIELD_display)
+
+        super(MultiChoiceField, self).contribute_to_class(cls, name)
+
 
 # Define a ``FileField`` that maps to filebrowser's ``FileBrowseField``
 # if available, falling back to Django's ``FileField`` otherwise.
