@@ -104,3 +104,13 @@ for field_id, field_path, field_name in extra_fields:
         raise ImproperlyConfigured(err % (field_id, field_name))
     CLASSES[field_id] = import_dotted_path(field_path)
     NAMES += ((field_id, _(field_name)),)
+
+# Similar to above but for widgets - expects a sequence of pairs,
+# each with a field ID as per above, and a dotted path to the custom
+# widget class to use for the corresponding form field.
+extra_widgets = getattr(settings, "FORMS_EXTRA_WIDGETS", [])
+for field_id, widget_path in extra_widgets:
+    if field_id not in CLASSES:
+        err = "ID %s in FORMS_EXTRA_WIDGETS does not match a field"
+        raise ImproperlyConfigured(err % field_id)
+    WIDGETS[field_id] = import_dotted_path(widget_path)
