@@ -28,6 +28,11 @@ class ThreadedCommentAdmin(CommentsAdmin):
         actions.pop("flag_comments")
         return actions
 
+    # Disable the 'Add' action for this model, fixed a crash if you try
+    # to create a comment from admin panel
+    def has_add_permission(self, request):
+        return False
+
 
 generic_comments = getattr(settings, "COMMENTS_APP", "") == "mezzanine.generic"
 if generic_comments and not settings.COMMENTS_DISQUS_SHORTNAME:
