@@ -81,7 +81,7 @@ class BaseGenericRelation(GenericRelation):
                 if name_string in [i.name for i, _ in
                                    cls._meta.get_fields_with_model()]:
                     continue
-                if not field.verbose_name:
+                if field.verbose_name is None:
                     field.verbose_name = self.verbose_name
                 cls.add_to_class(name_string, copy(field))
             # Add a getter function to the model we can use to retrieve
@@ -134,6 +134,13 @@ class BaseGenericRelation(GenericRelation):
         """
         pass
 
+    def value_from_object(self, obj):
+        """
+        Returns the value of this field in the given model instance.
+        Needed for Django 1.7: https://code.djangoproject.com/ticket/22552
+        """
+        return getattr(obj, self.attname).all()
+
 
 class CommentsField(BaseGenericRelation):
     """
