@@ -1,3 +1,7 @@
+from __future__ import unicode_literals
+from future.builtins import str
+
+from json import dumps
 
 from django.contrib.admin.views.decorators import staff_member_required
 from django.contrib.messages import error
@@ -7,11 +11,6 @@ from django.http import HttpResponse
 from django.shortcuts import redirect
 from django.utils.translation import ugettext_lazy as _
 
-try:
-    from json import dumps
-except ImportError:  # Python < 2.6
-    from django.utils.simplejson import dumps
-
 from mezzanine.conf import settings
 from mezzanine.generic.forms import ThreadedCommentForm, RatingForm
 from mezzanine.generic.models import Keyword
@@ -62,7 +61,7 @@ def initial_validation(request, prefix):
     if getattr(settings, login_required_setting_name, False):
         if not request.user.is_authenticated():
             request.session[posted_session_key] = request.POST
-            error(request, _("You must logged in. Please log in or "
+            error(request, _("You must be logged in. Please log in or "
                              "sign up to complete this action."))
             redirect_url = "%s?next=%s" % (settings.LOGIN_URL, reverse(prefix))
         elif posted_session_key in request.session:
